about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--src/libcollections/string.rs9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/libcollections/string.rs b/src/libcollections/string.rs
index 2cc225f50bc..43fcdfae4d6 100644
--- a/src/libcollections/string.rs
+++ b/src/libcollections/string.rs
@@ -613,7 +613,8 @@ impl String {
     ///
     /// # Failure
     ///
     /// Fails if `len` > current length.
     ///
     /// # Example
     ///
@@ -624,9 +625,9 @@ impl String {
     /// ```
     #[inline]
     #[unstable = "the failure conventions for strings are under development"]
-    pub fn truncate(&mut self, len: uint) {
-        assert!(self.as_slice().is_char_boundary(len));
-        self.vec.truncate(len)
+    pub fn truncate(&mut self, new_len: uint) {
+        assert!(self.as_slice().is_char_boundary(new_len));
+        self.vec.truncate(new_len)
     }
 
     /// Appends a byte to this string buffer.
@@ -613,7 +613,8 @@ impl String {
     /// # Failure
     ///
-    /// Fails if `len` > current length.
+    /// Fails if `new_len` > current length,
+    /// or if `new_len` is not a character boundary.
     ///
     /// # Example